@@ -2,4 +2,7 @@ from .behavior import BaseBehavior
 from .localizer import BaseLocalizer
 from .communicator import BaseCommunicator
 from .agent import Agent
-from .common import AgentLocation
\ No newline at end of file
+from .body import AgentType
+from .spawner import Spawner
+from .world import WorldModel, VisibleObjects
+from .common import *
