@@ -35,6 +35,7 @@ class Agent:
         self.monitor_socket = Server()
         self.behavior: BaseBehavior = behavior
         self.behavior.initialize(team_name)
+        self.behavior.body_model.agent_type = agent_type
 
     def done(self):
         self.global_socket.close()
@@ -87,11 +88,18 @@ class Agent:
                     self.done()
                     exit()
 
-    def start(self):
+    def handler(self):
         def signal_handler(sig, _):
             print('\nExiting!')
             sys.exit(0)
 
         signal.signal(signal.SIGINT, signal_handler)
+
+    def start(self, custom_handler=None):
+        if custom_handler:
+            custom_handler()
+        else:
+            self.handler()
+
         self.run()
         self.done()
