@@ -3,12 +3,16 @@ from .world import *
 from .localizer import BaseLocalizer
 from .network import Parser
 from .communicator import BaseCommunicator
-from .common import AgentLocation
+from .common import AgentLocation, Joint
 
 
 class BaseBehavior:
 
-    def __init__(self, beam_location: AgentLocation, localizer: BaseLocalizer = None, communicator: BaseCommunicator = None) -> None:
+    def __init__(
+            self,
+            beam_location: AgentLocation,
+            localizer: BaseLocalizer = None,
+            communicator: BaseCommunicator = None) -> None:
         self.beam_location = beam_location
         self.monitor_msg = ""
         self.initialized = False
@@ -22,10 +26,9 @@ class BaseBehavior:
 
         self.parser = Parser(world_model=self.world_model,
                              body_model=self.body_model,
-                             communicator=self.communicator                             
+                             communicator=self.communicator
                              )
-        
-        
+
         if self.communicator is not None:
             self.communicator.initialize(self.world_model, self.localizer)
 
@@ -54,10 +57,10 @@ class BaseBehavior:
 
     def compose_action(self):
         message = ""
-        for effector in EffectorJoints:
-            torque = self.body_model.compute_torque(effector)
-            effector_name = effector.to_string()
-            message += self.hj_effector(effector_name, torque)
+        for joint in Joint:
+            torque = self.body_model.compute_torque(joint)
+            joint_name = joint.effector_name
+            message += self.hj_effector(joint_name, torque)
 
         if self.communicator is not None:
             message += self.communicator.make_say_message()
@@ -94,7 +97,7 @@ class BaseBehavior:
         self.initialize_body()
         self.initialized = True
         return None
-    
+
     def think(self, message: str) -> str:
 
         parse_success = self.parser.parse(message)
@@ -111,13 +114,17 @@ class BaseBehavior:
         if self.localizer is not None:
             self.localizer.update()
 
+        # DOn't perform any action if we don't know where we are
+        if self.localizer.my_location.position is None:
+            return
+
         action = ""
         self.act()
 
         if self.communicator is not None:
             self.communicator.say()
             self.communicator.hear()
-            
+
         action += self.compose_action()
         return action
 
