@@ -7,4 +7,4 @@ class GroundTruthModel:
         self.ball_position = None
 
     def is_enabled(self):
-        return self.my_location.position != None and self.my_location.orientation != None and self.ball_position != None
+        return self.my_location.position is not None and self.my_location.orientation is not None and self.ball_position is not None
