@@ -4,6 +4,7 @@ from ..body import *
 from ..world import *
 from ..communicator import *
 from .constants import *
+from ..common import perceptor_to_joint
 
 
 class Parser:
@@ -17,7 +18,7 @@ class Parser:
         self.world_model: WorldModel = world_model
         self.body_model: BodyModel = body_model
         self.communicator: BaseCommunicator = communicator
-        
+
         self.side = Sides.LEFT
 
     def tokenise(self, s) -> List[str]:
@@ -76,7 +77,8 @@ class Parser:
     def __parse_accelerometer(self, string):
         rateX, rateY, rateZ = self.__get_xyz(string, "a")
 
-        #  Sometimes spurious (very high or NaN) readings come through. Clip them.
+        # Sometimes spurious (very high or NaN) readings come through. Clip
+        # them.
         spuriousThreshold = 20.0
         if ((abs(rateX) > spuriousThreshold)):
             rateX = 0
@@ -103,10 +105,12 @@ class Parser:
             (correctedRateX, correctedRateY, correctedRateZ))
 
     def __segment(self, string):
-        return re.findall(r'\(([^()]*(?:\(([^()]*(?:\((?:[^()]*(?:\([^()]*\)[^()]*)*)\)[^()]*)*)\)[^()]*)*)\)', string)
+        return re.findall(
+            r'\(([^()]*(?:\(([^()]*(?:\((?:[^()]*(?:\([^()]*\)[^()]*)*)\)[^()]*)*)\)[^()]*)*)\)',
+            string)
 
     def __parse_hinge_joint(self, string):
-        effector_name = joint_to_effector[self.__parser_helper("n", string)]
+        effector_name = perceptor_to_joint[self.__parser_helper("n", string)]
         effector_angle = float(self.__parser_helper("ax", string))
 
         self.body_model.set_current_angle(effector_name, effector_angle)
@@ -133,8 +137,8 @@ class Parser:
 
     def __parse_line(self, string):
         '''
-        Parse Line is not complete yet. There are multiple lines data coming from the server. We need to figure out how to 
-        process that. 
+        Parse Line is not complete yet. There are multiple lines data coming from the server. We need to figure out how to
+        process that.
 
         TODO: Need to undderstand the concept of the lines
         '''
@@ -156,7 +160,8 @@ class Parser:
         valid = False
 
         tokens = self.tokenise(string)
-        # based on the assumption that the max characters in a team name will be 100
+        # based on the assumption that the max characters in a team name will
+        # be 100
         valid = (len(tokens) == 30)
 
         if valid:
@@ -175,29 +180,33 @@ class Parser:
 
             if team_name == self.world_model.my_team_name:
                 self.world_model.teammate_info[agent_num].is_visible = True
-                self.world_model.teammate_info[agent_num].update_from_dict(player_info)
+                self.world_model.teammate_info[agent_num].update_from_dict(
+                    player_info)
             else:
                 self.world_model.opponent_info[agent_num].is_visible = True
-                self.world_model.opponent_info[agent_num].update_from_dict(player_info)
+                self.world_model.opponent_info[agent_num].update_from_dict(
+                    player_info)
 
         return valid
 
     def __reset_simple_non_visible_objects(self, string):
         for object in VisibleObjects:
-            if not re.search(f"[(]{object.value}\s", string):
+            if not re.search(f"[(]{object.value}\\s", string):
                 self.world_model.simple_vision_objects[object] = None
 
     def __is_player_visible(self, string, num, team):
-        regex = f"\(P\s+\(team\s+{team}\)\s+\(id\s+{num}\)"
+        regex = f"\\(P\\s+\\(team\\s+{team}\\)\\s+\\(id\\s+{num}\\)"
         return re.search(regex, string) is not None
 
     def __reset_player_information(self, string):
         for object in self.world_model.teammate_info.keys():
-            if not self.__is_player_visible(string, object, self.world_model.my_team_name):
+            if not self.__is_player_visible(
+                    string, object, self.world_model.my_team_name):
                 self.world_model.teammate_info[object].is_visible = False
 
         for object in self.world_model.opponent_info.keys():
-            if not self.__is_player_visible(string, object, self.world_model.opponent_team_name):
+            if not self.__is_player_visible(
+                    string, object, self.world_model.opponent_team_name):
                 self.world_model.opponent_info[object].is_visible = False
 
     def __parse_position_groundtruth(self, string):
@@ -266,8 +275,6 @@ class Parser:
                 valid = False
 
         return valid
-    
-
 
     def __parse_hear(self: 'Parser', string):
 
@@ -280,7 +287,6 @@ class Parser:
 
         valid = len(tokens) == 5
 
-    
         if not valid:
             return valid
 
@@ -288,7 +294,7 @@ class Parser:
 
         if len(tokens) == 5:
             team = tokens[i]
-            i+=1
+            i += 1
             if team != self.world_model.my_team_name:
                 self.world_model.opponent_team_name = team
                 return True
@@ -299,7 +305,7 @@ class Parser:
             is_self = True
         else:
             is_self = False
-        
+
         i += 2
 
         if i >= len(tokens):
@@ -312,11 +318,11 @@ class Parser:
 
         self.communicator.heard_message.update(
             message=message,
-            heard_time=hear_game_time, 
+            heard_time=hear_game_time,
             team_name=team,
             voice_orientation=orientation
-            )
-   
+        )
+
         return valid
 
     def parse(self, string):
