@@ -33,7 +33,9 @@ class PlayModes(Enum):
 
 class ForceResistancePerceptors(Enum):
     RF = 'rf'
+    RF1 = 'rf1'
     LF = 'lf'
+    LF1 = 'lf1'
 
 
 class VisibleObjects(Enum):
@@ -47,7 +49,23 @@ class VisibleObjects(Enum):
     G2R = 'G2R'
     BALL = 'B'
 
+    @property
+    def global_position(self):
+        return _WORLD_OBJECTS_GLOBAL_POSITIONS[self.name]
+
 
 class WorldDimensions(Enum):
     HEIGHT = 20.0
     WIDTH = 30.0
+
+
+_WORLD_OBJECTS_GLOBAL_POSITIONS = {
+    "F1R": (15.0, 10.0, 0.0),
+    "F1L": (-15.0, 10.0, 0.0),
+    "F2R": (15.0, -10.0, 0.0),
+    "F2L": (-15.0, -10.0, 0.0),
+    "G1L": (-15.0, 1.05, 0.8),
+    "G2L": (-15.0, -1.05, 0.8),
+    "G1R": (15.0, 1.05, 0.8),
+    "G2R": (15.0, -1.05, 0.8),
+}
